@@ -943,17 +943,17 @@ class PSO_min():
             
 
 class ShanGeTu():
-    def __init__(self,map_path = 'map.dll',reverse = False):
+    def __init__(self,map_path = 'map.dll',map_data = None,reverse = False):
         self.grid_size = 0
         self.cell_size = 0
         self.line_size = 0
-        self.load_map(map_path,reverse = reverse)                        #读取地图数据
-        self.pic_backgroud = self.backgroud()  #画网格
-        self.draw_barrier()                    #画障碍物方格，跟上一步共同组合成完整的背景图片
+        self.__load_map(map_path,map_data,reverse = reverse)                        #读取地图数据
+        self.pic_backgroud = self.__backgroud()  #画网格
+        self.__draw_barrier()                    #画障碍物方格，跟上一步共同组合成完整的背景图片
         #self.draw_way(way_data=way_data)
         #self.save()                            #保存起来
-    @classmethod   
-    def backgroud(self):
+        
+    def __backgroud(self):
         '''
             Function:
             ---------
@@ -992,8 +992,8 @@ class ShanGeTu():
                 py.draw.line(backgroud,[0,0,0],[i*(self.cell_size+self.line_size),0],[i*(self.cell_size+self.line_size),pic_size])
                 py.draw.line(backgroud,[0,0,0],[0,i*(self.cell_size+self.line_size)],[pic_size,i*(self.cell_size+self.line_size)])
             return backgroud
-    @classmethod
-    def load_map(self,map_path,reverse = False):
+
+    def __load_map(self,map_path,map_data,reverse = False):
         '''
         Function:
         ---------
@@ -1007,15 +1007,20 @@ class ShanGeTu():
         -------
             None
         '''
-        with open(map_path,'r') as f:
-            self.map_data = f.readlines()
-        for k,i in enumerate(self.map_data):
-            self.map_data[k]= i.strip('\n')
+        if map_data == None:
+            with open(map_path,'r') as f:
+                self.map_data = f.readlines()
+            for k,i in enumerate(self.map_data):
+                self.map_data[k]= i.strip('\n')
+        else:
+            self.map_data = []
+            for  i in map_data:
+                i = [str(j) for j in i]
+                self.map_data.append(''.join(i))
         if reverse == True:
             self.map_data.reverse()
         self.grid_size = len(self.map_data[0])
-    @classmethod
-    def draw_barrier(self):
+    def __draw_barrier(self):
         for i in range(len(self.map_data[0])):
             for j in range(len(self.map_data[0])):
                 if self.map_data[i][j] == '1':
@@ -1079,8 +1084,7 @@ class ShanGeTu():
             if  reverse == True:
                 self.pic_backgroud = flip(self.pic_backgroud,False,True)
             py.image.save(self.pic_backgroud,filename)
-    @classmethod
-    def seek_corner_point(self,way_data = [1,2,3,4]):
+    def __seek_corner_point(self,way_data = [1,2,3,4]):
         '''
             Function:
             ---------
@@ -1107,7 +1111,7 @@ class ShanGeTu():
                 special_pot_list.append(way_data[i])
                 special_pot_key_list.append(1)
                 a_1 = way_data[i+1]-way_data[i]
-                if self.is_near_obstacle(way_data[i],way_data[i+1]):
+                if self.__is_near_obstacle(way_data[i],way_data[i+1]):
                     special_pot_list.append([way_data[i],way_data[i+1]])
                     special_pot_key_list.append(2)
         special_pot_list.append((self.grid_size**2)-1)
@@ -1115,8 +1119,8 @@ class ShanGeTu():
         print(special_pot_list)
         print(special_pot_key_list)
         return special_pot_list, special_pot_key_list
-    @classmethod
-    def is_near_obstacle(self,point_a,point_b):
+
+    def __is_near_obstacle(self,point_a,point_b):
         '''
             Function:
             ---------
@@ -1159,8 +1163,8 @@ class ShanGeTu():
                     return True
                 else:
                     return False
-    @classmethod            
-    def calc_abs_x_y(self,point_data = 0):
+
+    def __calc_abs_x_y(self,point_data = 0):
         '''
             Function:
             ---------
@@ -1194,7 +1198,7 @@ class ShanGeTu():
 
     def opti_way(self, way_data = [1,2,3,4]):
         #Step 1:找到转折点，以及擦边点，统称变异点
-        a_1,b_1 = self.seek_corner_point(way_data=way_data)
+        a_1,b_1 = self.__seek_corner_point(way_data=way_data)
         #Step 2:计算其绝对像素坐标，并打印出来看看
         print('a_1：',a_1)
         print('b_1：',b_1)
@@ -1202,13 +1206,13 @@ class ShanGeTu():
         abs_xy_list = []
         try:
             for i in a_1:
-                x,y = self.calc_abs_x_y(point_data=i)
+                x,y = self.__calc_abs_x_y(point_data=i)
                 py.draw.circle(self.pic_shangetu,[50,100,200],[x,self.backgroud_size - y],3)
                 abs_xy_list.append([x,y])
         except:
             self.pic_shangetu = self.pic_backgroud.copy()
             for i in a_1:
-                x,y = self.calc_abs_x_y(point_data=i)
+                x,y = self.__calc_abs_x_y(point_data=i)
                 abs_xy_list.append([x,y])
             #self.draw_pot(x,y)
         # Step 3: 优化
@@ -1219,7 +1223,7 @@ class ShanGeTu():
                 print(abs_xy_list[i],abs_xy_list[i+1],abs_xy_list[i+2],'中间点为擦边点！')
                 pass    
             else:
-                result = self.trigon_opt(abs_xy_list[i],abs_xy_list[i+1],abs_xy_list[i+2],b_1[i:i+3])
+                result = self.__trigon_opt(abs_xy_list[i],abs_xy_list[i+1],abs_xy_list[i+2],b_1[i:i+3])
                 if result == None:
                     print(abs_xy_list[i],abs_xy_list[i+1],abs_xy_list[i+2],'能直接连接！')
                     del abs_xy_list[i+1]
@@ -1247,8 +1251,8 @@ class ShanGeTu():
             py.draw.line(self.pic_shangetu,[255,150,50],[abs_xy_list[i][0],self.backgroud_size-abs_xy_list[i][1]],[abs_xy_list[i+1][0],self.backgroud_size-abs_xy_list[i+1][1]],3)
 
         #self.save('栅格图优化.jpg')
-    @classmethod        
-    def trigon_opt(self,pot_1,pot_2,pot_3,key_list):
+        #       
+    def __trigon_opt(self,pot_1,pot_2,pot_3,key_list):
         '''
             Function:
             --------
@@ -1267,16 +1271,16 @@ class ShanGeTu():
                 若pot为None，则代表可疑直连，否则pot为三角的极限顶点。
         '''
 
-        result = self.is_accross_barrier(pot_1,pot_3)
+        result = self.__is_accross_barrier(pot_1,pot_3)
         if result[0] == True:
-            pot = self.deep_opt(pot_1,pot_2,pot_3)
+            pot = self.__deep_opt(pot_1,pot_2,pot_3)
             #input('wait for ldd...')
             return pot
 
         else:
             return None
-    @classmethod       
-    def is_accross_barrier(self,pot_1 ,pot_2):
+
+    def __is_accross_barrier(self,pot_1 ,pot_2):
         '''
             Function:
             ---------
@@ -1311,8 +1315,8 @@ class ShanGeTu():
             #else:
             #    print('判断节点:',self.grid_size-1-y_1,x_1,'结果为可通行')
         return [False,[]]                                #100个点都判断完了，返回False
-    @classmethod
-    def deep_opt(self,pot_1,pot_2,pot_3):
+     
+    def __deep_opt(self,pot_1,pot_2,pot_3):
         '''
         function:
         ---------
@@ -1342,18 +1346,18 @@ class ShanGeTu():
         for i in range(1,STEP+1):
             x_1 = pot_2[0] + int(deta_x*i)
             y_1 = pot_2[1] + int(deta_y*i)
-            r_1 = self.is_accross_barrier(pot_1,[x_1,y_1])
-            r_2 = self.is_accross_barrier([x_1,y_1],pot_3)
+            r_1 = self.__is_accross_barrier(pot_1,[x_1,y_1])
+            r_2 = self.__is_accross_barrier([x_1,y_1],pot_3)
             if r_1[0]:
                 #print('找到临界障碍物:',r_1[1])
-                new_pot_2 = self.seek_shortest_vertice(r_1[1],pot_1,[x_1,y_1],pot_3)
+                new_pot_2 = self.__seek_shortest_vertice(r_1[1],pot_1,[x_1,y_1],pot_3)
                 py.draw.circle(self.pic_shangetu,[255,0,0],[new_pot_2[0],self.backgroud_size - new_pot_2[1]],3)
                 #self.save()
                 #input('wait...')
                 return new_pot_2
             elif r_2[0]:
                 #print('找到临界障碍物:',r_2[1])
-                new_pot_2 = self.seek_shortest_vertice(r_2[1],pot_1,[x_1,y_1],pot_3)
+                new_pot_2 = self.__seek_shortest_vertice(r_2[1],pot_1,[x_1,y_1],pot_3)
                 py.draw.circle(self.pic_shangetu,[255,0,0],[new_pot_2[0],self.backgroud_size - new_pot_2[1]],3)
                 #self.save()
                 #input('wait...')
@@ -1362,8 +1366,8 @@ class ShanGeTu():
                 pass
                 #print('继续...')
         #self.save()
-    @classmethod    
-    def seek_shortest_vertice(self,grid,pot_1,pot_2,pot_3):
+        
+    def __seek_shortest_vertice(self,grid,pot_1,pot_2,pot_3):
         # Step 1: 先找到四个顶点坐标
         x = grid[0]
         y = grid[1]
@@ -1387,14 +1391,14 @@ class ShanGeTu():
                 key = k
                 yuzhi = s
         return vertices[key]
-    @classmethod
-    def calc_way_lenght(self):
-        self.way_lenght = 0
-        for i in range(len(self.final_opt_way)-1):
-            a_1 = self.final_opt_way[i]
-            b_1 = self.final_opt_way[i+1]
-            self.way_lenght += (((a_1[0]-b_1[0])**2)+((a_1[1]-b_1[1])**2))**0.5
-        self.way_lenght = self.way_lenght/self.cell_size
+     
+    # def calc_way_lenght(self):
+    #     self.way_lenght = 0
+    #     for i in range(len(self.final_opt_way)-1):
+    #         a_1 = self.final_opt_way[i]
+    #         b_1 = self.final_opt_way[i+1]
+    #         self.way_lenght += (((a_1[0]-b_1[0])**2)+((a_1[1]-b_1[1])**2))**0.5
+    #     self.way_lenght = self.way_lenght/self.cell_size
         
         
 
